Index: src/sas/qtgui/MainWindow/UI/DataExplorerUI.ui
===================================================================
--- src/sas/qtgui/MainWindow/UI/DataExplorerUI.ui	(revision cd2cc7458970e179039a783e9409f48c4c1fca0d)
+++ src/sas/qtgui/MainWindow/UI/DataExplorerUI.ui	(revision 61a92d4c3e2e9b0410555517d59b1e8503c98ff4)
@@ -7,5 +7,5 @@
     <x>0</x>
     <y>0</y>
-    <width>405</width>
+    <width>501</width>
     <height>630</height>
    </rect>
@@ -133,5 +133,5 @@
         </layout>
        </item>
-       <item row="0" column="1">
+       <item row="0" column="1" colspan="2">
         <spacer name="horizontalSpacer_7">
          <property name="orientation">
@@ -146,5 +146,36 @@
         </spacer>
        </item>
-       <item row="2" column="0">
+       <item row="1" column="0" colspan="3">
+        <widget class="QTreeView" name="treeView">
+         <property name="contextMenuPolicy">
+          <enum>Qt::NoContextMenu</enum>
+         </property>
+         <property name="acceptDrops">
+          <bool>true</bool>
+         </property>
+         <property name="editTriggers">
+          <set>QAbstractItemView::NoEditTriggers</set>
+         </property>
+         <property name="dragEnabled">
+          <bool>true</bool>
+         </property>
+         <property name="dragDropOverwriteMode">
+          <bool>true</bool>
+         </property>
+         <property name="dragDropMode">
+          <enum>QAbstractItemView::DropOnly</enum>
+         </property>
+         <property name="defaultDropAction">
+          <enum>Qt::CopyAction</enum>
+         </property>
+         <property name="selectionMode">
+          <enum>QAbstractItemView::ExtendedSelection</enum>
+         </property>
+         <attribute name="headerVisible">
+          <bool>false</bool>
+         </attribute>
+        </widget>
+       </item>
+       <item row="2" column="0" colspan="2">
         <layout class="QGridLayout" name="gridLayout_2">
          <item row="0" column="0" rowspan="2">
@@ -197,9 +228,14 @@
           <widget class="QComboBox" name="cbFitting">
            <property name="sizePolicy">
-            <sizepolicy hsizetype="Minimum" vsizetype="Fixed">
+            <sizepolicy hsizetype="MinimumExpanding" vsizetype="Fixed">
              <horstretch>0</horstretch>
              <verstretch>0</verstretch>
             </sizepolicy>
            </property>
+           <property name="font">
+            <font>
+             <pointsize>12</pointsize>
+            </font>
+           </property>
            <property name="sizeAdjustPolicy">
             <enum>QComboBox::AdjustToContents</enum>
@@ -231,34 +267,16 @@
         </layout>
        </item>
-       <item row="1" column="0" colspan="2">
-        <widget class="QTreeView" name="treeView">
-         <property name="contextMenuPolicy">
-          <enum>Qt::NoContextMenu</enum>
-         </property>
-         <property name="acceptDrops">
-          <bool>true</bool>
-         </property>
-         <property name="editTriggers">
-          <set>QAbstractItemView::NoEditTriggers</set>
-         </property>
-         <property name="dragEnabled">
-          <bool>true</bool>
-         </property>
-         <property name="dragDropOverwriteMode">
-          <bool>true</bool>
-         </property>
-         <property name="dragDropMode">
-          <enum>QAbstractItemView::DropOnly</enum>
-         </property>
-         <property name="defaultDropAction">
-          <enum>Qt::CopyAction</enum>
-         </property>
-         <property name="selectionMode">
-          <enum>QAbstractItemView::ExtendedSelection</enum>
-         </property>
-         <attribute name="headerVisible">
-          <bool>false</bool>
-         </attribute>
-        </widget>
+       <item row="2" column="2">
+        <spacer name="horizontalSpacer">
+         <property name="orientation">
+          <enum>Qt::Horizontal</enum>
+         </property>
+         <property name="sizeHint" stdset="0">
+          <size>
+           <width>160</width>
+           <height>20</height>
+          </size>
+         </property>
+        </spacer>
        </item>
       </layout>
Index: src/sas/qtgui/ObjectFactory.py
===================================================================
--- src/sas/qtgui/ObjectFactory.py	(revision 0215e0a678125ef1cadea03d546abfd942ea528d)
+++ 	(revision )
@@ -1,21 +1,0 @@
-import sys
-
-this = sys.modules[__name__]
-
-this._objects = {}
-
-def addObject(obj_name, obj):
-    this._objects[obj_name] = obj
-
-def deleteObject(obj_name):
-    if obj_name in this._objects:
-        del this._objects[obj_name]
-
-def getObject(obj_name):
-    return this._objects[obj_name] if obj_name in this._objects else None
-
-def listObjects():
-    return this._objects.keys()
-
-
-
Index: src/sas/qtgui/Perspectives/Fitting/FittingWidget.py
===================================================================
--- src/sas/qtgui/Perspectives/Fitting/FittingWidget.py	(revision 180bd545166c0e0d674354e554dec53998b492c6)
+++ src/sas/qtgui/Perspectives/Fitting/FittingWidget.py	(revision 61a92d4c3e2e9b0410555517d59b1e8503c98ff4)
@@ -122,4 +122,11 @@
         self.model_parameters = None
         self.lstParams.setAlternatingRowColors(True)
+        stylesheet = """
+            QTreeView{
+                alternate-background-color: #f6fafb;
+                background: #e8f4fc;
+            }
+        """
+        self.lstParams.setStyleSheet(stylesheet)
 
         # Poly model displayed in poly list
@@ -572,4 +579,7 @@
         self.q_range_min, self.q_range_max, self.npts, self.log_points, self.weighting = \
             self.options_widget.state()
+        # set Q range labels on the main tab
+        self.lblMinRangeDef.setText(str(self.q_range_min))
+        self.lblMaxRangeDef.setText(str(self.q_range_max))
         self.onPlot()
 
Index: src/sas/qtgui/Perspectives/Fitting/OptionsWidget.py
===================================================================
--- src/sas/qtgui/Perspectives/Fitting/OptionsWidget.py	(revision 180bd545166c0e0d674354e554dec53998b492c6)
+++ src/sas/qtgui/Perspectives/Fitting/OptionsWidget.py	(revision 61a92d4c3e2e9b0410555517d59b1e8503c98ff4)
@@ -141,6 +141,7 @@
         #print "MODEL CHANGED for property: %s. The value is now: %s" % \
         #    (MODEL[top.row()], str(self.model.item(top.row()).text()))
+
         # update if there's something to update
-        if str(self.model.item(top.row()).text()): #and 'RANGE' in MODEL[top.row()]:
+        if str(self.model.item(top.row()).text()):
             self.plot_signal.emit()
 
Index: src/sas/qtgui/Utilities/ObjectLibrary.py
===================================================================
--- src/sas/qtgui/Utilities/ObjectLibrary.py	(revision 61a92d4c3e2e9b0410555517d59b1e8503c98ff4)
+++ src/sas/qtgui/Utilities/ObjectLibrary.py	(revision 61a92d4c3e2e9b0410555517d59b1e8503c98ff4)
@@ -0,0 +1,27 @@
+import sys
+
+this = sys.modules[__name__]
+
+this._objects = {}
+
+def addObject(obj_name, obj):
+    this._objects[obj_name] = obj
+
+def deleteObjectByRef(obj):
+    for name, object in this._objects.iteritems():
+        if object == obj:
+            del this._objects[name]
+            break
+
+def deleteObjectByName(obj_name):
+    if obj_name in this._objects:
+        del this._objects[obj_name]
+
+def getObject(obj_name):
+    return this._objects[obj_name] if obj_name in this._objects else None
+
+def listObjects():
+    return this._objects.keys()
+
+
+

Index: src/sas/qtgui/Perspectives/Fitting/FittingPerspective.py
===================================================================
--- src/sas/qtgui/Perspectives/Fitting/FittingPerspective.py	(revision 0215e0a678125ef1cadea03d546abfd942ea528d)
+++ src/sas/qtgui/Perspectives/Fitting/FittingPerspective.py	(revision 61a92d4c3e2e9b0410555517d59b1e8503c98ff4)
@@ -6,5 +6,5 @@
 
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
-import sas.qtgui.ObjectFactory as ObjectFactory
+import sas.qtgui.Utilities.ObjectLibrary as ObjectLibrary
 
 from FittingWidget import FittingWidget
@@ -75,6 +75,6 @@
         """
         tab	= FittingWidget(parent=self.parent, data=data, id=self.maxIndex+1)
-        # Add this tab to the object factory so it can be retrieved by scripting/jupyter
-        ObjectFactory.addObject(self.tabName(), tab)
+        # Add this tab to the object library so it can be retrieved by scripting/jupyter
+        ObjectLibrary.addObject(self.tabName(), tab)
         self.tabs.append(tab)
         self.maxIndex += 1
@@ -96,5 +96,5 @@
         if len(self.tabs) <= 1:
             return
-        ObjectFactory.deleteObject(self.tabs[index].accessibleName())
+        ObjectLibrary.deleteObjectByRef(self.tabs[index])
         del self.tabs[index]
         self.removeTab(index)